# mypy-boto3-eks

[![PyPI - mypy-boto3-eks](https://img.shields.io/pypi/v/mypy-boto3-eks.svg?color=blue)](https://pypi.org/project/mypy-boto3-eks)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-eks.svg?color=blue)](https://pypi.org/project/mypy-boto3-eks)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.EKS 1.14.0](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/eks.html#EKS) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.2.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to install

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `EKS` service.

```bash
python -m pip install boto3-stubs[eks]
```

## How to use

### Client annotations

`EKSClient` provides annotations for `boto3.client("eks")`.

```python
import boto3

from mypy_boto3_eks import EKSClient
from mypy_boto3_eks.paginator import (
    ListClustersPaginator,
    ListFargateProfilesPaginator,
    ListNodegroupsPaginator,
    ListUpdatesPaginator,
)
from mypy_boto3_eks.type_defs import AutoScalingGroupTypeDef, ...
from mypy_boto3_eks.waiter import (
    ClusterActiveWaiter,
    ClusterDeletedWaiter,
    NodegroupActiveWaiter,
    NodegroupDeletedWaiter,
)

client: EKSClient = boto3.client("eks")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: EKSClient = session.client("eks")
```

### Paginators annotations

`mypy_boto3_eks.paginator` module contains type annotations for all paginators.

```python

client: EKSClient = boto3.client("eks")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_clusters_paginator: ListClustersPaginator = client.get_paginator("list_clusters")
list_fargate_profiles_paginator: ListFargateProfilesPaginator = client.get_paginator("list_fargate_profiles")
list_nodegroups_paginator: ListNodegroupsPaginator = client.get_paginator("list_nodegroups")
list_updates_paginator: ListUpdatesPaginator = client.get_paginator("list_updates")
```


### Waiters annotations

`mypy_boto3_eks.waiter` module contains type annotations for all waiters.

```python

client: EKSClient = boto3.client("eks")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
cluster_active_waiter: ClusterActiveWaiter = client.get_waiter("cluster_active")
cluster_deleted_waiter: ClusterDeletedWaiter = client.get_waiter("cluster_deleted")
nodegroup_active_waiter: NodegroupActiveWaiter = client.get_waiter("nodegroup_active")
nodegroup_deleted_waiter: NodegroupDeletedWaiter = client.get_waiter("nodegroup_deleted")
```





### Typed dictionations

`mypy_boto3_eks.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python

def get_structure() -> AutoScalingGroupTypeDef:
    return {
      ...
    }
```


## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_eks` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("eks")

session_client = boto3.Session().client("eks")
```
